# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from featureflags_protobuf import service_pb2 as featureflags__protobuf_dot_service__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class FeatureFlagsStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.exchange = channel.unary_unary(
                '/featureflags_protobuf.service.FeatureFlags/exchange',
                request_serializer=featureflags__protobuf_dot_service__pb2.ExchangeRequest.SerializeToString,
                response_deserializer=featureflags__protobuf_dot_service__pb2.ExchangeReply.FromString,
                )
        self.Exchange = channel.unary_unary(
                '/featureflags_protobuf.service.FeatureFlags/Exchange',
                request_serializer=featureflags__protobuf_dot_service__pb2.ExchangeRequest.SerializeToString,
                response_deserializer=featureflags__protobuf_dot_service__pb2.ExchangeReply.FromString,
                )
        self.store_stats = channel.unary_unary(
                '/featureflags_protobuf.service.FeatureFlags/store_stats',
                request_serializer=featureflags__protobuf_dot_service__pb2.StoreStatsTask.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.StoreStats = channel.unary_unary(
                '/featureflags_protobuf.service.FeatureFlags/StoreStats',
                request_serializer=featureflags__protobuf_dot_service__pb2.StoreStatsTask.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class FeatureFlagsServicer(object):
    """Missing associated documentation comment in .proto file."""

    def exchange(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Exchange(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def store_stats(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StoreStats(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FeatureFlagsServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'exchange': grpc.unary_unary_rpc_method_handler(
                    servicer.exchange,
                    request_deserializer=featureflags__protobuf_dot_service__pb2.ExchangeRequest.FromString,
                    response_serializer=featureflags__protobuf_dot_service__pb2.ExchangeReply.SerializeToString,
            ),
            'Exchange': grpc.unary_unary_rpc_method_handler(
                    servicer.Exchange,
                    request_deserializer=featureflags__protobuf_dot_service__pb2.ExchangeRequest.FromString,
                    response_serializer=featureflags__protobuf_dot_service__pb2.ExchangeReply.SerializeToString,
            ),
            'store_stats': grpc.unary_unary_rpc_method_handler(
                    servicer.store_stats,
                    request_deserializer=featureflags__protobuf_dot_service__pb2.StoreStatsTask.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'StoreStats': grpc.unary_unary_rpc_method_handler(
                    servicer.StoreStats,
                    request_deserializer=featureflags__protobuf_dot_service__pb2.StoreStatsTask.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'featureflags_protobuf.service.FeatureFlags', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class FeatureFlags(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def exchange(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/featureflags_protobuf.service.FeatureFlags/exchange',
            featureflags__protobuf_dot_service__pb2.ExchangeRequest.SerializeToString,
            featureflags__protobuf_dot_service__pb2.ExchangeReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Exchange(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/featureflags_protobuf.service.FeatureFlags/Exchange',
            featureflags__protobuf_dot_service__pb2.ExchangeRequest.SerializeToString,
            featureflags__protobuf_dot_service__pb2.ExchangeReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def store_stats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/featureflags_protobuf.service.FeatureFlags/store_stats',
            featureflags__protobuf_dot_service__pb2.StoreStatsTask.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StoreStats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/featureflags_protobuf.service.FeatureFlags/StoreStats',
            featureflags__protobuf_dot_service__pb2.StoreStatsTask.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
