# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: featureflags_protobuf/backend.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from hiku.protobuf import query_pb2 as hiku_dot_protobuf_dot_query__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from featureflags_protobuf import graph_pb2 as featureflags__protobuf_dot_graph__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#featureflags_protobuf/backend.proto\x12\x1d\x66\x65\x61tureflags_protobuf.backend\x1a\x19hiku/protobuf/query.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a!featureflags_protobuf/graph.proto\"\x13\n\x02Id\x12\r\n\x05value\x18\x01 \x01(\t\"\'\n\x07LocalId\x12\r\n\x05value\x18\x01 \x01(\t\x12\r\n\x05scope\x18\x02 \x01(\t\"\x7f\n\x08\x45itherId\x12/\n\x02id\x18\x01 \x01(\x0b\x32!.featureflags_protobuf.backend.IdH\x00\x12:\n\x08local_id\x18\x02 \x01(\x0b\x32&.featureflags_protobuf.backend.LocalIdH\x00\x42\x06\n\x04kind\",\n\x06SignIn\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\"\t\n\x07SignOut\"@\n\nEnableFlag\x12\x32\n\x07\x66lag_id\x18\x01 \x01(\x0b\x32!.featureflags_protobuf.backend.Id\"A\n\x0b\x44isableFlag\x12\x32\n\x07\x66lag_id\x18\x01 \x01(\x0b\x32!.featureflags_protobuf.backend.Id\"?\n\tResetFlag\x12\x32\n\x07\x66lag_id\x18\x01 \x01(\x0b\x32!.featureflags_protobuf.backend.Id\"\xde\x02\n\x08\x41\x64\x64\x43heck\x12\x38\n\x08local_id\x18\x01 \x01(\x0b\x32&.featureflags_protobuf.backend.LocalId\x12\x33\n\x08variable\x18\x02 \x01(\x0b\x32!.featureflags_protobuf.backend.Id\x12=\n\x08operator\x18\x03 \x01(\x0e\x32+.featureflags_protobuf.graph.Check.Operator\x12\x16\n\x0cvalue_string\x18\x04 \x01(\tH\x00\x12\x16\n\x0cvalue_number\x18\x05 \x01(\x01H\x00\x12\x35\n\x0fvalue_timestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x12\x35\n\tvalue_set\x18\x07 \x01(\x0b\x32 .featureflags_protobuf.graph.SetH\x00\x42\x06\n\x04kind\"\xb5\x01\n\x0c\x41\x64\x64\x43ondition\x12\x32\n\x07\x66lag_id\x18\x01 \x01(\x0b\x32!.featureflags_protobuf.backend.Id\x12\x38\n\x08local_id\x18\x02 \x01(\x0b\x32&.featureflags_protobuf.backend.LocalId\x12\x37\n\x06\x63hecks\x18\x03 \x03(\x0b\x32\'.featureflags_protobuf.backend.EitherId\"K\n\x10\x44isableCondition\x12\x37\n\x0c\x63ondition_id\x18\x01 \x01(\x0b\x32!.featureflags_protobuf.backend.Id\"\x9f\x04\n\tOperation\x12@\n\x0b\x65nable_flag\x18\x01 \x01(\x0b\x32).featureflags_protobuf.backend.EnableFlagH\x00\x12\x42\n\x0c\x64isable_flag\x18\x02 \x01(\x0b\x32*.featureflags_protobuf.backend.DisableFlagH\x00\x12\x44\n\radd_condition\x18\x03 \x01(\x0b\x32+.featureflags_protobuf.backend.AddConditionH\x00\x12L\n\x11\x64isable_condition\x18\x04 \x01(\x0b\x32/.featureflags_protobuf.backend.DisableConditionH\x00\x12<\n\tadd_check\x18\x05 \x01(\x0b\x32\'.featureflags_protobuf.backend.AddCheckH\x00\x12>\n\nreset_flag\x18\x06 \x01(\x0b\x32(.featureflags_protobuf.backend.ResetFlagH\x00\x12\x38\n\x07sign_in\x18\x07 \x01(\x0b\x32%.featureflags_protobuf.backend.SignInH\x00\x12:\n\x08sign_out\x18\x08 \x01(\x0b\x32&.featureflags_protobuf.backend.SignOutH\x00\x42\x04\n\x02op\"q\n\x07Request\x12<\n\noperations\x18\x01 \x03(\x0b\x32(.featureflags_protobuf.backend.Operation\x12(\n\x05query\x18\x02 \x01(\x0b\x32\x19.hiku.protobuf.query.Node\"<\n\x05Reply\x12\x33\n\x06result\x18\x01 \x01(\x0b\x32#.featureflags_protobuf.graph.Result2\xbc\x01\n\x07\x42\x61\x63kend\x12Y\n\x04\x63\x61ll\x12&.featureflags_protobuf.backend.Request\x1a$.featureflags_protobuf.backend.Reply\"\x03\x88\x02\x01\x12V\n\x04\x43\x61ll\x12&.featureflags_protobuf.backend.Request\x1a$.featureflags_protobuf.backend.Reply\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'featureflags_protobuf.backend_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_BACKEND'].methods_by_name['call']._options = None
  _globals['_BACKEND'].methods_by_name['call']._serialized_options = b'\210\002\001'
  _globals['_ID']._serialized_start=165
  _globals['_ID']._serialized_end=184
  _globals['_LOCALID']._serialized_start=186
  _globals['_LOCALID']._serialized_end=225
  _globals['_EITHERID']._serialized_start=227
  _globals['_EITHERID']._serialized_end=354
  _globals['_SIGNIN']._serialized_start=356
  _globals['_SIGNIN']._serialized_end=400
  _globals['_SIGNOUT']._serialized_start=402
  _globals['_SIGNOUT']._serialized_end=411
  _globals['_ENABLEFLAG']._serialized_start=413
  _globals['_ENABLEFLAG']._serialized_end=477
  _globals['_DISABLEFLAG']._serialized_start=479
  _globals['_DISABLEFLAG']._serialized_end=544
  _globals['_RESETFLAG']._serialized_start=546
  _globals['_RESETFLAG']._serialized_end=609
  _globals['_ADDCHECK']._serialized_start=612
  _globals['_ADDCHECK']._serialized_end=962
  _globals['_ADDCONDITION']._serialized_start=965
  _globals['_ADDCONDITION']._serialized_end=1146
  _globals['_DISABLECONDITION']._serialized_start=1148
  _globals['_DISABLECONDITION']._serialized_end=1223
  _globals['_OPERATION']._serialized_start=1226
  _globals['_OPERATION']._serialized_end=1769
  _globals['_REQUEST']._serialized_start=1771
  _globals['_REQUEST']._serialized_end=1884
  _globals['_REPLY']._serialized_start=1886
  _globals['_REPLY']._serialized_end=1946
  _globals['_BACKEND']._serialized_start=1949
  _globals['_BACKEND']._serialized_end=2137
# @@protoc_insertion_point(module_scope)
