# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: featureflags_protobuf/graph.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!featureflags_protobuf/graph.proto\x12\x1b\x66\x65\x61tureflags_protobuf.graph\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\"h\n\x03Ref\x12\x11\n\x07Project\x18\x01 \x01(\tH\x00\x12\x0e\n\x04\x46lag\x18\x02 \x01(\tH\x00\x12\x13\n\tCondition\x18\x03 \x01(\tH\x00\x12\x0f\n\x05\x43heck\x18\x04 \x01(\tH\x00\x12\x12\n\x08Variable\x18\x05 \x01(\tH\x00\x42\x04\n\x02to\"\x14\n\x03Set\x12\r\n\x05items\x18\x01 \x03(\t\"\xa7\x01\n\x08Variable\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x38\n\x04type\x18\x03 \x01(\x0e\x32*.featureflags_protobuf.graph.Variable.Type\"G\n\x04Type\x12\x0f\n\x0b__DEFAULT__\x10\x00\x12\n\n\x06STRING\x10\x01\x12\n\n\x06NUMBER\x10\x02\x12\r\n\tTIMESTAMP\x10\x03\x12\x07\n\x03SET\x10\x04\"\xee\x03\n\x05\x43heck\x12\n\n\x02id\x18\x01 \x01(\t\x12\x32\n\x08variable\x18\x02 \x01(\x0b\x32 .featureflags_protobuf.graph.Ref\x12=\n\x08operator\x18\x03 \x01(\x0e\x32+.featureflags_protobuf.graph.Check.Operator\x12\x16\n\x0cvalue_string\x18\x04 \x01(\tH\x00\x12\x16\n\x0cvalue_number\x18\x05 \x01(\x01H\x00\x12\x35\n\x0fvalue_timestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x12\x35\n\tvalue_set\x18\x07 \x01(\x0b\x32 .featureflags_protobuf.graph.SetH\x00\"\xbf\x01\n\x08Operator\x12\x0f\n\x0b__DEFAULT__\x10\x00\x12\t\n\x05\x45QUAL\x10\x01\x12\r\n\tLESS_THAN\x10\x02\x12\x11\n\rLESS_OR_EQUAL\x10\x03\x12\x10\n\x0cGREATER_THAN\x10\x04\x12\x14\n\x10GREATER_OR_EQUAL\x10\x05\x12\x0c\n\x08\x43ONTAINS\x10\x06\x12\x0b\n\x07PERCENT\x10\x07\x12\n\n\x06REGEXP\x10\x08\x12\x0c\n\x08WILDCARD\x10\t\x12\n\n\x06SUBSET\x10\n\x12\x0c\n\x08SUPERSET\x10\x0b\x42\x06\n\x04kind\"I\n\tCondition\x12\n\n\x02id\x18\x01 \x01(\t\x12\x30\n\x06\x63hecks\x18\x02 \x03(\x0b\x32 .featureflags_protobuf.graph.Ref\"\xe6\x01\n\x04\x46lag\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x31\n\x07project\x18\x03 \x01(\x0b\x32 .featureflags_protobuf.graph.Ref\x12+\n\x07\x65nabled\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x34\n\nconditions\x18\x05 \x03(\x0b\x32 .featureflags_protobuf.graph.Ref\x12.\n\noverridden\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"i\n\x07Project\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\r\x12\x33\n\tvariables\x18\x03 \x03(\x0b\x32 .featureflags_protobuf.graph.Ref\"\xea\x01\n\x04Root\x12.\n\x04\x66lag\x18\x01 \x01(\x0b\x32 .featureflags_protobuf.graph.Ref\x12/\n\x05\x66lags\x18\x02 \x03(\x0b\x32 .featureflags_protobuf.graph.Ref\x12\x32\n\x08projects\x18\x03 \x03(\x0b\x32 .featureflags_protobuf.graph.Ref\x12\x15\n\rauthenticated\x18\x05 \x01(\x08\x12\x36\n\x0c\x66lags_by_ids\x18\x06 \x03(\x0b\x32 .featureflags_protobuf.graph.Ref\"\xae\x06\n\x06Result\x12/\n\x04Root\x18\x01 \x01(\x0b\x32!.featureflags_protobuf.graph.Root\x12\x41\n\x07Project\x18\x02 \x03(\x0b\x32\x30.featureflags_protobuf.graph.Result.ProjectEntry\x12;\n\x04\x46lag\x18\x03 \x03(\x0b\x32-.featureflags_protobuf.graph.Result.FlagEntry\x12\x45\n\tCondition\x18\x04 \x03(\x0b\x32\x32.featureflags_protobuf.graph.Result.ConditionEntry\x12=\n\x05\x43heck\x18\x05 \x03(\x0b\x32..featureflags_protobuf.graph.Result.CheckEntry\x12\x43\n\x08Variable\x18\x06 \x03(\x0b\x32\x31.featureflags_protobuf.graph.Result.VariableEntry\x1aT\n\x0cProjectEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x33\n\x05value\x18\x02 \x01(\x0b\x32$.featureflags_protobuf.graph.Project:\x02\x38\x01\x1aN\n\tFlagEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32!.featureflags_protobuf.graph.Flag:\x02\x38\x01\x1aX\n\x0e\x43onditionEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32&.featureflags_protobuf.graph.Condition:\x02\x38\x01\x1aP\n\nCheckEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x31\n\x05value\x18\x02 \x01(\x0b\x32\".featureflags_protobuf.graph.Check:\x02\x38\x01\x1aV\n\rVariableEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32%.featureflags_protobuf.graph.Variable:\x02\x38\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'featureflags_protobuf.graph_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_RESULT_PROJECTENTRY']._options = None
  _globals['_RESULT_PROJECTENTRY']._serialized_options = b'8\001'
  _globals['_RESULT_FLAGENTRY']._options = None
  _globals['_RESULT_FLAGENTRY']._serialized_options = b'8\001'
  _globals['_RESULT_CONDITIONENTRY']._options = None
  _globals['_RESULT_CONDITIONENTRY']._serialized_options = b'8\001'
  _globals['_RESULT_CHECKENTRY']._options = None
  _globals['_RESULT_CHECKENTRY']._serialized_options = b'8\001'
  _globals['_RESULT_VARIABLEENTRY']._options = None
  _globals['_RESULT_VARIABLEENTRY']._serialized_options = b'8\001'
  _globals['_REF']._serialized_start=131
  _globals['_REF']._serialized_end=235
  _globals['_SET']._serialized_start=237
  _globals['_SET']._serialized_end=257
  _globals['_VARIABLE']._serialized_start=260
  _globals['_VARIABLE']._serialized_end=427
  _globals['_VARIABLE_TYPE']._serialized_start=356
  _globals['_VARIABLE_TYPE']._serialized_end=427
  _globals['_CHECK']._serialized_start=430
  _globals['_CHECK']._serialized_end=924
  _globals['_CHECK_OPERATOR']._serialized_start=725
  _globals['_CHECK_OPERATOR']._serialized_end=916
  _globals['_CONDITION']._serialized_start=926
  _globals['_CONDITION']._serialized_end=999
  _globals['_FLAG']._serialized_start=1002
  _globals['_FLAG']._serialized_end=1232
  _globals['_PROJECT']._serialized_start=1234
  _globals['_PROJECT']._serialized_end=1339
  _globals['_ROOT']._serialized_start=1342
  _globals['_ROOT']._serialized_end=1576
  _globals['_RESULT']._serialized_start=1579
  _globals['_RESULT']._serialized_end=2393
  _globals['_RESULT_PROJECTENTRY']._serialized_start=1969
  _globals['_RESULT_PROJECTENTRY']._serialized_end=2053
  _globals['_RESULT_FLAGENTRY']._serialized_start=2055
  _globals['_RESULT_FLAGENTRY']._serialized_end=2133
  _globals['_RESULT_CONDITIONENTRY']._serialized_start=2135
  _globals['_RESULT_CONDITIONENTRY']._serialized_end=2223
  _globals['_RESULT_CHECKENTRY']._serialized_start=2225
  _globals['_RESULT_CHECKENTRY']._serialized_end=2305
  _globals['_RESULT_VARIABLEENTRY']._serialized_start=2307
  _globals['_RESULT_VARIABLEENTRY']._serialized_end=2393
# @@protoc_insertion_point(module_scope)
