# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: featureflags_protobuf/service.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from hiku.protobuf import query_pb2 as hiku_dot_protobuf_dot_query__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from featureflags_protobuf import graph_pb2 as featureflags__protobuf_dot_graph__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#featureflags_protobuf/service.proto\x12\x1d\x66\x65\x61tureflags_protobuf.service\x1a\x19hiku/protobuf/query.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a!featureflags_protobuf/graph.proto\"R\n\x08Variable\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x38\n\x04type\x18\x02 \x01(\x0e\x32*.featureflags_protobuf.graph.Variable.Type\"w\n\tFlagUsage\x12\x0c\n\x04name\x18\x01 \x01(\t\x12,\n\x08interval\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0enegative_count\x18\x03 \x01(\r\x12\x16\n\x0epositive_count\x18\x04 \x01(\r\"\xd8\x01\n\x0f\x45xchangeRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\r\x12:\n\tvariables\x18\x03 \x03(\x0b\x32\'.featureflags_protobuf.service.Variable\x12=\n\x0b\x66lags_usage\x18\x04 \x03(\x0b\x32(.featureflags_protobuf.service.FlagUsage\x12(\n\x05query\x18\x05 \x01(\x0b\x32\x19.hiku.protobuf.query.Node\"U\n\rExchangeReply\x12\x0f\n\x07version\x18\x01 \x01(\r\x12\x33\n\x06result\x18\x02 \x01(\x0b\x32#.featureflags_protobuf.graph.Result\"\x7f\n\x0eStoreStatsTask\x12\x0f\n\x07\x66lag_id\x18\x01 \x01(\t\x12,\n\x08interval\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0enegative_count\x18\x03 \x01(\r\x12\x16\n\x0epositive_count\x18\x04 \x01(\r2\x9b\x03\n\x0c\x46\x65\x61tureFlags\x12m\n\x08\x65xchange\x12..featureflags_protobuf.service.ExchangeRequest\x1a,.featureflags_protobuf.service.ExchangeReply\"\x03\x88\x02\x01\x12j\n\x08\x45xchange\x12..featureflags_protobuf.service.ExchangeRequest\x1a,.featureflags_protobuf.service.ExchangeReply\"\x00\x12Y\n\x0bstore_stats\x12-.featureflags_protobuf.service.StoreStatsTask\x1a\x16.google.protobuf.Empty\"\x03\x88\x02\x01\x12U\n\nStoreStats\x12-.featureflags_protobuf.service.StoreStatsTask\x1a\x16.google.protobuf.Empty\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'featureflags_protobuf.service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_FEATUREFLAGS'].methods_by_name['exchange']._options = None
  _globals['_FEATUREFLAGS'].methods_by_name['exchange']._serialized_options = b'\210\002\001'
  _globals['_FEATUREFLAGS'].methods_by_name['store_stats']._options = None
  _globals['_FEATUREFLAGS'].methods_by_name['store_stats']._serialized_options = b'\210\002\001'
  _globals['_VARIABLE']._serialized_start=194
  _globals['_VARIABLE']._serialized_end=276
  _globals['_FLAGUSAGE']._serialized_start=278
  _globals['_FLAGUSAGE']._serialized_end=397
  _globals['_EXCHANGEREQUEST']._serialized_start=400
  _globals['_EXCHANGEREQUEST']._serialized_end=616
  _globals['_EXCHANGEREPLY']._serialized_start=618
  _globals['_EXCHANGEREPLY']._serialized_end=703
  _globals['_STORESTATSTASK']._serialized_start=705
  _globals['_STORESTATSTASK']._serialized_end=832
  _globals['_FEATUREFLAGS']._serialized_start=835
  _globals['_FEATUREFLAGS']._serialized_end=1246
# @@protoc_insertion_point(module_scope)
